==> totvs-log-web-foundation-0.0.9.tgz: package/src/lib/services/intl/change-language/change-language.component.ts <==
import { I18nBaseService } from 'totvs-log-base-foundation';
import { Component, OnInit, Input, ViewChild, Output, EventEmitter } from '@angular/core';
import { ThfRadioGroupOption, ThfModalAction, ThfModalComponent } from '@totvs/thf-ui';
import { IChangeLanguageLiterals } from './change-language-literals.interface';

@Component({
  selector: 'lib-change-language',
  templateUrl: './change-language.component.html',
  styleUrls: ['./change-language.component.css']
})
export class ChangeLanguageComponent implements OnInit {

  @Input() literals: IChangeLanguageLiterals = {
    modalTitle: 'changeLanguage',
    radioGroupLabel: 'selectLanguage',
    saveAction: 'save',
    cancelAction: 'cancel'
  };

  @Output() afterChangeLanguage = new EventEmitter<string>();

  @ViewChild(ThfModalComponent, { static: true }) changeLanguageModal: ThfModalComponent;

  private _primaryAction: ThfModalAction;
  public get primaryAction(): ThfModalAction {
    return this._primaryAction;
  }

  private _secondaryAction: ThfModalAction;
  public get secondaryAction(): ThfModalAction {
    return this._secondaryAction;
  }

  private _languageOptions: Array<ThfRadioGroupOption> = [];
  public get languageOptions(): Array<ThfRadioGroupOption> {
    return this._languageOptions;
  }

  selectedLanguage: string;

  constructor(public i18n: I18nBaseService) { }

  ngOnInit() { }

  public openChangeLanguageModal() {
    this.setModalActions();
    this.setLanguageOptions();
    this.selectedLanguage = this.i18n.getLanguage();
    this.changeLanguageModal.open();
  }

  private setModalActions() {

    this._primaryAction = {
      label: this.i18n.literals[this.literals.saveAction],
      action: () => {
        this.changeLanguage();
      }
    };

    this._secondaryAction = {
      label: this.i18n.literals[this.literals.cancelAction],
      action: () => {
        this.changeLanguageModal.close();
      }
    };
  }

  private setLanguageOptions() {
    this._languageOptions = [];
    this.i18n.getSupportedLanguages().forEach(supportedLanguage => {
      this._languageOptions.push({
        label: this.i18n.literals[supportedLanguage.language],
        value: supportedLanguage.language
      });
    });
  }

  private changeLanguage() {
    const subscribe = this.i18n.updateOptions({ language: this.selectedLanguage }).subscribe(() => {
      subscribe.unsubscribe();
      this.afterChangeLanguage.emit(this.selectedLanguage);
      this.changeLanguageModal.close();
    });
  }
}

==> totvs-log-web-foundation-1.0.0.tgz: package/src/lib/services/intl/change-language/change-language.component.ts <==
import { I18nBaseService } from 'totvs-log-base-foundation';
import { Component, OnInit, Input, ViewChild, Output, EventEmitter } from '@angular/core';
import { PoRadioGroupOption, PoModalAction, PoModalComponent } from '@portinari/portinari-ui';
import { IChangeLanguageLiterals } from './change-language-literals.interface';

@Component({
  selector: 'lib-change-language',
  templateUrl: './change-language.component.html',
  styleUrls: ['./change-language.component.css']
})
export class ChangeLanguageComponent implements OnInit {

  @Input() literals: IChangeLanguageLiterals = {
    modalTitle: 'changeLanguage',
    radioGroupLabel: 'selectLanguage',
    saveAction: 'save',
    cancelAction: 'cancel'
  };

  @Output() afterChangeLanguage = new EventEmitter<string>();

  @ViewChild(PoModalComponent, { static: true }) changeLanguageModal: PoModalComponent;

  private _primaryAction: PoModalAction;
  public get primaryAction(): PoModalAction {
    return this._primaryAction;
  }

  private _secondaryAction: PoModalAction;
  public get secondaryAction(): PoModalAction {
    return this._secondaryAction;
  }

  private _languageOptions: Array<PoRadioGroupOption> = [];
  public get languageOptions(): Array<PoRadioGroupOption> {
    return this._languageOptions;
  }

  selectedLanguage: string;

  constructor(public i18n: I18nBaseService) { }

  ngOnInit() { }

  public openChangeLanguageModal() {
    this.setModalActions();
    this.setLanguageOptions();
    this.selectedLanguage = this.i18n.getLanguage();
    this.changeLanguageModal.open();
  }

  private setModalActions() {

    this._primaryAction = {
      label: this.i18n.literals[this.literals.saveAction],
      action: () => {
        this.changeLanguage();
      }
    };

    this._secondaryAction = {
      label: this.i18n.literals[this.literals.cancelAction],
      action: () => {
        this.changeLanguageModal.close();
      }
    };
  }

  private setLanguageOptions() {
    this._languageOptions = [];
    this.i18n.getSupportedLanguages().forEach(supportedLanguage => {
      this._languageOptions.push({
        label: this.i18n.literals[supportedLanguage.language],
        value: supportedLanguage.language
      });
    });
  }

  private changeLanguage() {
    const subscribe = this.i18n.updateOptions({ language: this.selectedLanguage }).subscribe(() => {
      this.afterChangeLanguage.emit(this.selectedLanguage);
      this.changeLanguageModal.close();
    }, () => {}, () => {
      subscribe.unsubscribe();
    });
  }
}
